@@ -1000,9 +1000,9 @@ async def spawn_inference_server(
             )
             robots_to_control.remove(robot)
 
-    assert all(
-        isinstance(robot, BaseManipulator) for robot in robots_to_control
-    ), "All robots must be manipulators for AI control"
+    assert all(isinstance(robot, BaseManipulator) for robot in robots_to_control), (
+        "All robots must be manipulators for AI control"
+    )
 
     # Get the modal host and port here
     _, _, server_info = await setup_ai_control(
@@ -1092,9 +1092,9 @@ async def start_ai_control(
             )
             robots_to_control.remove(robot)
 
-    assert all(
-        isinstance(robot, BaseManipulator) for robot in robots_to_control
-    ), "All robots must be manipulators for AI control"
+    assert all(isinstance(robot, BaseManipulator) for robot in robots_to_control), (
+        "All robots must be manipulators for AI control"
+    )
 
     # Get the modal host and port here
     model, model_spawn_config, server_info = await setup_ai_control(
@@ -1132,6 +1132,9 @@ async def start_ai_control(
         cameras_keys_mapping=query.cameras_keys_mapping,
         detect_instruction=query.prompt,
         selected_camera_id=query.selected_camera_id,
+        angle_format=query.angle_format,
+        min_angle=query.min_angle,
+        max_angle=query.max_angle,
     )
 
     return AIControlStatusResponse(
